@@ -362,9 +362,6 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
                 }
                 if (strcmp(function, GET_NEW_MESSAGES) == 0) {
                     g_debug("GET_NEW_MESSAGES");
-                    //xmlDocPtr request;
-                    //request = xmlParseDoc("<Request class=\"messages\" function = \"getInboxMessages\">\
-                                           <Params/></Request>");
                     num = parser_new_messages(tmp);
                     g_free(tmp);
                     g_debug("num = %d",num);
